# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:target, :array_matching => :all, :parent => Puppet::Parameter::WlsProperty) do
  include EasyType::ArrayProperty

  desc <<-DESC
    An array of target names.

    The array of targets for this resource. A target can be a WebLogic Server, a WebLogic cluster, or a JMS Server.
    When specifying a `target`, you'll also have to specify `targettype`. Here is an example on how you can specify a `target`.

        ..{ 'aResource':
          ...
          target     => ['myServer','myCluster'],
          targettype => ['Server','Cluster'],
          ...
        }

    here is an example on specifying the `target` and `targettype` for a regular WebLogic cluster:

        wls_cluster{ 'aCluster':
          ...
          target     => ['myServer','myCluster'],
          targettype => ['Server','Cluster'],
          ...
        }

  DESC

  maps_to('Targets/')

  on_apply do
    apply_paths_with_target(resource.target, resource.targettype)
  end
  data_type('Optional[Array[String]]')
end

child_of(:wls_safagent) { autorequire_when('SAFAgent') }
child_of(:wls_server) { autorequire_when('Server') }
child_of(:wls_cluster) { autorequire_when('Cluster') }
child_of(:wls_jmsserver) { autorequire_when('JMSServer') }
child_of(:wls_migrateble_target) { autorequire_when('MigratableTarget') }

private

def autorequire_when(type_name)
  return_value = []
  targets = self[:target] || []
  targets.each_with_index do |value, index|
    return_value << full_name(value) if self[:targettype][index] == type_name
  end
end

def full_name(name)
  "#{domain}/#{name}"
end
