# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:frontendhttpsport, :parent => Puppet::Parameter::WlsProperty) do
  include EasyType::Types::Integer
  include EasyType::Validators::PortNumber

  desc <<-DESC
  The name of the secure HTTP port to which all redirected URLs will be sent.  Sets the FrontendHTTPSPort for the default webserver (not virtual hosts) for all the servers in the cluster. Provides a method to ensure that the webapp will always have the correct PORT information, even when the request is coming through a firewall or a proxy. If this parameter is configured, the HOST header will be ignored and the information in this parameter will be used in its place, when constructing the absolute urls for redirects.

  Here is an example on how to use this:

      wls_cluster { 'aCluster':
        ...
        frontendhttpport => '9000',
        ...
      }
  DESC

  data_type("Optional[Variant[Enum['absent'],Integer]]")

  maps_to('FrontendHTTPSPort')
end
