# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:ds_row_prefetch_size, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  If row prefetching is enabled, specifies the number of result set rows to prefetch for a client.  The optimal prefetch size depends on the particulars of the query. In general, increasing this number will increase performance, until a particular value is reached. At that point further increases do not result in any significant performance increase. Very rarely will increased performance result from exceeding 100 rows. The default value should be reasonable for most situations.

  An example on how to use this:

      wls_datasource {a_wls_datasource :
         ...
         ds_row_prefetch_size => '48'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_datasource:ds_row_prefetch_size']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC
  include EasyType::Types::Integer
  data_type("Optional[Variant[Enum['absent'],Integer]]")

  maps_to('JDBCResource/%<datasource_name>s/JDBCDataSourceParams/%<datasource_name>s/RowPrefetchSize')
end
