# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:oracle_active_gridlink, :parent => Puppet::Parameter::WlsProperty) do
  include Puppet_X::EnterpriseModules::WebLogic::Types::NumberedBoolean

  desc <<-DESC
  Indicates a configured Active GridLink datasource. This attributed is set to <code>true</code> when using the console to create an Active GridLink datasource. It is ignored if FanEnabled is <code>true</code> or OnsNodeList is a non-null string.

  An example on how to use this:

      wls_datasource {a_wls_datasource :
         ...
         oracle_active_gridlink => 1,
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_datasource:oracle_active_gridlink']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  data_type("Optional[Variant[Enum['absent'],Integer[0,1]]]")

  maps_to('JDBCResource/%<datasource_name>s/JDBCOracleParams/%<datasource_name>s/ActiveGridlink')
end
