# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:pool_count_of_refresh_failures_till_disable, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  Specifies the number of reconnect failures allowed before WebLogic Server disables a connection pool to minimize the delay in handling the connection request caused by a database failure.  Zero means it is disabled.

  An example on how to use this:

      wls_datasource {a_wls_datasource :
         ...
         pool_count_of_refresh_failures_till_disable => '2'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_datasource:pool_count_of_refresh_failures_till_disable']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC
  include EasyType::Types::Integer
  data_type("Optional[Variant[Enum['absent'],Integer]]")

  maps_to('JDBCResource/%<datasource_name>s/JDBCConnectionPoolParams/%<datasource_name>s/CountOfRefreshFailuresTillDisable')
end
