# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:pool_remove_infected_connections, :parent => Puppet::Parameter::WlsProperty) do
  include Puppet_X::EnterpriseModules::WebLogic::Types::NumberedBoolean

  desc <<-DESC
  Specifies whether a connection will be removed from the connection pool after the application uses the underlying vendor connection object.  If you disable removing infected connections, you must make sure that the database connection is suitable for reuse by other applications.  When set to <code>true</code> (the default), the physical connection is not returned to the connection pool after the application closes the logical connection. Instead, the physical connection is closed and recreated.  When set to <code>false</code>, when the application closes the logical connection, the physical connection is returned to the connection pool and can be reused by the application or by another application.

  An example on how to use this:

      wls_datasource {a_wls_datasource :
         ...
         pool_remove_infected_connections => 1,
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_datasource:pool_remove_infected_connections']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  data_type("Optional[Variant[Enum['absent'],Integer[0,1]]]")

  maps_to('JDBCResource/%<datasource_name>s/JDBCConnectionPoolParams/%<datasource_name>s/RemoveInfectedConnections')
end
