# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:maxcapacity, :parent => Puppet::Parameter::WlsProperty) do
  include EasyType::Types::Integer

  desc <<-DESC
    The max capacity of the datasource.

  DESC

  data_type("Optional[Variant[Enum['absent'],Integer]]")

  maps_to('JDBCResource/%<datasource_name>s/JDBCConnectionPoolParams/%<datasource_name>s/MaxCapacity')

  on_apply do
    #
    # If the maximum capacity will be changed to a value that is lower then the current minimiumcapacity
    # WebLogic will return an error. To fix this, when this situation arrises, we need to set the value of mincapacity first
    #
    if resource.provider.mincapacity.to_s != 'absent' && value < resource.provider.mincapacity.to_i
      Puppet.debug('First setting mincapacity because requested maxcapacity is lower then current mincapacity')
      key = 'JDBCResource/%<datasource_name>s/JDBCConnectionPoolParams/%<datasource_name>s/MinCapacity'
      path = Kernel.format("#{type_path}/#{resource[key_name]}/#{key}", resource.to_hash)
      wls_config.set(path, resource[:mincapacity])
      #
      # To make sure WebLogic knows about it. Save it. Because the other properties expect an edit mode, restart the edit mode
      #
      wls_config.save
      wls_config.edit
    end
    super()
  end
end
