# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:mincapacity, :parent => Puppet::Parameter::WlsProperty) do
  include EasyType::Types::Integer

  desc <<-DESC
    The min capacity of the datasource.

  DESC

  data_type("Optional[Variant[Enum['absent'],Integer]]")

  maps_to('JDBCResource/%<datasource_name>s/JDBCConnectionPoolParams/%<datasource_name>s/MinCapacity')

  on_apply do
    #
    # If the minimum capacity will be changed to a value that is higher then the current maxmiumcapacity
    # WebLogic will return an error. To fix this, when this situation arrises, we need to set the value of mincapacity first
    #
    if resource.provider.maxcapacity.to_s != 'absent' && value > resource.provider.maxcapacity.to_i
      Puppet.debug('First setting maxcapacity because requested mincapacity is higher then current maxcapacity')
      key = 'JDBCResource/%<datasource_name>s/JDBCConnectionPoolParams/%<datasource_name>s/MaxCapacity'
      path = Kernel.format("#{type_path}/#{resource[key_name]}/#{key}", resource.to_hash)
      wls_config.set(path, resource[:maxcapacity])
      #
      # To make sure WebLogic knows about it. Save it. Because the other properties expect an edit mode, restart the edit mode
      #
      wls_config.save
      wls_config.edit
    end
    super()
  end
end
