# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:enable_ee_compliant_classloading_for_embedded_adapters, :parent => Puppet::Parameter::WlsProperty) do
  extend  Puppet_X::EnterpriseModules::WebLogic::DomainPaths # Changes the actual path for domain resource
  include Puppet_X::EnterpriseModules::WebLogic::Types::NumberedBoolean

  desc <<-DESC
  Specifies the class loading behavior for embedded adapters. If you enable this option, embedded adapters deployed to all partitions in the domain will use Java EE compliant class loading. The embedded adapter's classes will be accessible from other modules in the same application.

  An example on how to use this:

      wls_domain {a_wls_domain :
         ...
         enable_ee_compliant_classloading_for_embedded_adapters => 1,
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_domain:enable_ee_compliant_classloading_for_embedded_adapters']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  data_type("Optional[Variant[Enum['absent'],Integer[0,1]]]")

  maps_to('EnableEECompliantClassloadingForEmbeddedAdapters')
end
