# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:jta_recovery_site_name, :parent => Puppet::Parameter::WlsProperty) do
  extend Puppet_X::EnterpriseModules::WebLogic::DomainPaths # Changes the actual path for domain resource

  desc <<-DESC
  The name of the site whose transactions this site/domain will recover in the event that intra-cluster transaction service migration is not successful or efficient.

  An example on how to use this:

      wls_domain {a_wls_domain :
         ...
         jta_recovery_site_name => 'a_value'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_domain:jta_recovery_site_name']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  data_type('Optional[String]')

  maps_to('JTA/%<domain_name>s/RecoverySiteName')
end
