# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:jta_wsat_transport_security_mode, :parent => Puppet::Parameter::WlsProperty) do
  extend Puppet_X::EnterpriseModules::WebLogic::DomainPaths # Changes the actual path for domain resource

  desc <<-DESC
   Specifies transport security mode required by WebService Transaction endpoints. Transport Security options: <ul> <li>SSLNotRequired All WebService Transaction protocol messages are exchanged over the HTTP channel.</li>  <li>SSLRequired All WebService Transaction protocol messages are and can only be exchanged over the HTTPS.</li>  <li>ClientCertRequired All WebService Transaction protocol messages are and can only be exchanged over the HTTPS, and WLS enforces the presence of client certificate </li> </ul>

  An example on how to use this:

      wls_domain {a_wls_domain :
         ...
         jta_wsat_transport_security_mode => 'SSLNotRequired'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_domain:jta_wsat_transport_security_mode']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  data_type('Optional[String]')

  maps_to('JTA/%<domain_name>s/WSATTransportSecurityMode')
end
