# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:security_connection_filter_rules, :array_matching => :all, :parent => Puppet::Parameter::WlsProperty) do
  extend Puppet_X::EnterpriseModules::WebLogic::DomainPaths # Changes the actual path for domain resource
  include EasyType::ArrayProperty

  desc <<-DESC
  The rules used by any connection filter that implements the <tt>ConnectionFilterRulesListener</tt> interface. When using the default implementation and when no rules are specified, all connections are accepted. The default implementation rules are in the format: <tt>target localAddress localPort action protocols</tt>.   This attribute replaces the deprecated ConnectionFilterRules attribute on the SecurityMBean.

  An example on how to use this:

      wls_domain { 'appsvcs/appsvcs':
        security_connection_filter_rules => [
            '8.8.8.8 * * allow t3 t3s iiop iiops com',
            '8.8.8.9 * * allow t3 t3s iiop iiops com',
        ],
        security_connection_filter       => 'weblogic.security.net.ConnectionFilterImpl',
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_domain:security_connection_filter_rules']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  data_type('Optional[Array[String]]')

  on_apply do
    wls_config.execute(template('wls_config/wls_server/set_security_connection_filer_rules.py.erb', binding))
  end

  maps_to('SecurityConfiguration/%<domain_name>s/ConnectionFilterRules')
end
