# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:security_nonce_timeout_seconds, :parent => Puppet::Parameter::WlsProperty) do
  extend Puppet_X::EnterpriseModules::WebLogic::DomainPaths # Changes the actual path for domain resource

  desc <<-DESC
  Returns the value of the nonce timeout in seconds.

  An example on how to use this:

      wls_domain {a_wls_domain :
         ...
         security_nonce_timeout_seconds => '120'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_domain:security_nonce_timeout_seconds']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC
  include EasyType::Types::Integer
  data_type("Optional[Variant[Enum['absent'],Integer]]")

  maps_to('SecurityConfiguration/%<domain_name>s/NonceTimeoutSeconds')
end
