# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:partition_life_cycle_timeout_val, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  The number of seconds a force shutdown operation waits before timing out. If the operation does not complete within the configured timeout period, the partition will shutdown automatically if the state of the server at that time was <code>SHUTTING_DOWN</code>. <p/> A value of <code>0</code> means that the partition will wait indefinitely for the life cycle operation to complete.

  An example on how to use this:

      wls_domain_partition {a_wls_domain_partition :
         ...
         partition_life_cycle_timeout_val => '30'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_domain_partition:partition_life_cycle_timeout_val']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  data_type("Optional[Variant[Enum['absent'],Integer]]")

  maps_to('PartitionLifeCycleTimeoutVal')
end
