# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:machine_match_expression, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  Get the machine tag expression to use when selecting machine names.  If the MachineMatchType is "name", each value will either match a machine name exactly or, if specified with a trailing '*' suffix, will match multiple machine names. If the MachineMatchType is "tag", the values will match all of the machines that have all of the tag values.

  An example on how to use this:

      wls_dynamic_cluster {a_wls_dynamic_cluster :
         ...
         machine_match_expression => 'a_value'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_dynamic_cluster:machine_match_expression']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  data_type('Optional[String]')

  maps_to('MachineMatchExpression')
end
