# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:directory, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  The path name to the file system directory where the file store maintains its data files. <ul> <li>When targeting a file store to a migratable target, the store directory must be accessible from all candidate server members in the migratable target.</li> <li>For highest availability, use either a SAN (Storage Area Network) or other reliable shared storage.</li> <li>Use of NFS mounts is discouraged, but supported. Most NFS mounts are not transactionally safe by default, and, to ensure transactional correctness, need to be configured using your NFS vendor documentation in order to honor synchronous write requests.</li> <li>For <code>SynchronousWritePolicy</code> of <code>Direct-Write-With-Cache</code>, see <a href='#getCacheDirectory'>Cache Directory. </li> <li>Additional O/S tuning may be required if the directory is hosted by Microsoft Windows, see <a href='#getSynchronousWritePolicy'>Synchronous Write Policy for details.</li></ul>

  An example on how to use this:

      wls_file_persistence_store {a_wls_file_persistence_store :
         ...
         directory => 'a_value'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_file_persistence_store:directory']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  data_type('Optional[String]')

  maps_to('Directory')
end
