# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:connection_url, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  The URL that WebLogic Server will use to contact the JNDI provider. The syntax of this URL depends on which JNDI provider is being used. For WebLogic JMS, leave this field blank if you are referencing WebLogic JMS objects within the same cluster.  This value corresponds to the standard JNDI property, <code>java.naming.provider.url</code>.  Note: If this value is not specified, look-ups will be performed on the JNDI server within the WebLogic Server instance where this connection factory is deployed.

  An example on how to use this:

      wls_foreign_server {a_wls_foreign_server :
         ...
         connection_url => 'a_value'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_foreign_server:connection_url']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  data_type('Optional[String]')

  maps_to('ConnectionURL')
end
