# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:user_name, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  The optional user name the adapter uses to access the bridge destination.  All operations on the specified destination are done using this user name and the corresponding password. Therefore, the User Name/Password for the source and target destinations must have permission to the access the underlying destinations in order for the messaging bridge to work.

  An example on how to use this:

      wls_jms_bridge_destination {a_wls_jms_bridge_destination :
         ...
         user_name => 'a_value'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_jms_bridge_destination:user_name']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  data_type('Optional[String]')

  maps_to('UserName')
end
