# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:jndi_name, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  The global JNDI name used to look up the destination within the JNDI namespace.  In a clustered environment, this name is propagated to the entire cluster. If you want the JNDI name to be bound only on the local server, and not propagated to the rest of the cluster, then use the <code>Local JNDI Name</code> parameter.  If not specified, the destination name will not be advertised through the global JNDI namespace.

  An example on how to use this:

      wls_jms_queue {a_wls_jms_queue :
         ...
         jndi_name => 'a_value'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_jms_queue:jndi_name']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  data_type('Optional[String]')

  maps_to('JNDIName')
end
