# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:template, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  The JMS template from which the destination is derived. A template provides an efficient means of defining multiple destinations with similar configuration values.  If a JMS template is specified, destination parameters that are set to their default values will instead inherit their values from the JMS template at run-time. However, if a JMS template is not defined, then the configuration values for the destination must be specified as part of the destination.  Although you can dynamically modify the configuration of a JMS template, the configuration values on a destination are static.

  An example on how to use this:

      wls_jms_queue {a_wls_jms_queue :
         ...
         template => 'a_value'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_jms_queue:template']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  data_type('Optional[String]')

  maps_to('Template')
end
