# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:delivery_expiration_logging_policy, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  The policy that defines what information about the message is logged when the Expiration Policy is set to Log. The valid logging policy values are: <ul> <li> %header% - All JMS header fields are logged. <li> %properties% - All user-defined properties are logged. <li> JMSDeliveryTime - This WebLogic JMS-specific extended header field is logged. <li> JMSRedeliveryLimit - This WebLogic JMS-specific extended header field is logged. <li> foo  - Any valid JMS header field or user-defined property is logged. </ul>  When specifying multiple values, enter them as a comma-separated list. The <code>%header%</code> and <code>%properties% </code> values are not case sensitive. For example, you could use <code>"%header%,%properties%"</code> for all the JMS header fields and user properties. However, the enumeration of individual JMS header fields and user-defined properties are case sensitive. To enumerate only individual JMS header fields you could use <code>"%header, name, address, city, state, zip"</code>.  Note: The <code>JMSMessageID</code> field is always logged and cannot be turned off. Therefore, if the Expiration Logging Policy is not defined (i.e., null) or is defined as an empty string, then the output to the log file contains only the <code>JMSMessageID</code> of the message.

  An example on how to use this:

      wls_jms_template {a_wls_jms_template :
         ...
         delivery_expiration_logging_policy => 'a_value'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_jms_template:delivery_expiration_logging_policy']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  data_type('Optional[String]')

  maps_to('DeliveryFailureParams/%<template_name>s/ExpirationLoggingPolicy')
end
