# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:override_delivery_mode, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  The delivery mode assigned to all messages that arrive at the destination regardless of the DeliveryMode specified by the message producer.  A value of <tt>No-Delivery</tt> specifies that the DeliveryMode will not be overridden.  Note: This attribute is dynamically configurable, but only incoming messages are impacted; stored messages are not impacted.

  An example on how to use this:

      wls_jms_template {a_wls_jms_template :
         ...
         override_delivery_mode => 'No-Delivery'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_jms_template:override_delivery_mode']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  data_type('Optional[String]')

  maps_to('DeliveryParamsOverrides/%<template_name>s/DeliveryMode')
end
