# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:multicast_time_to_live, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  The number of routers that a message traverses en route to a consumer. A value of 1 limits the message to one subnet (which prevents it from traversing any routers).  This value is independent of the JMSExpirationTime value.   <!-- Gets the "time-to-live" element -->

  An example on how to use this:

      wls_jms_topic {a_wls_jms_topic :
         ...
         multicast_time_to_live => 1,
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_jms_topic:multicast_time_to_live']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC
  include EasyType::Types::Integer
  data_type("Optional[Variant[Enum['absent'],Integer]]")

  maps_to('Multicast/%<topic_name>s/MulticastTimeToLive')
end
