# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:unit_of_order_routing, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  Determines how a distributed destination member is selected as the destination for a message that is part of a unit-of-order. Hash, indicates that a message producer computes the member destination from the <code>hashCode</code> of the unit-of-order. PathService indicates that the configured Path Service determines the member destination.  Unit-of-Order Routing can be set programmatically with WLProducer, or administratively on the connection factory or destination.   Unit of Order Routing is not dynamically configurable.

  An example on how to use this:

      wls_jms_topic {a_wls_jms_topic :
         ...
         unit_of_order_routing => 'Hash'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_jms_topic:unit_of_order_routing']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  data_type('Optional[String]')

  maps_to('UnitOfOrderRouting')
end
