# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:allows_persistent_downgrade, :parent => Puppet::Parameter::WlsProperty) do
  include Puppet_X::EnterpriseModules::WebLogic::Types::NumberedBoolean

  desc <<-DESC
  Specifies whether JMS clients will get an exception when sending persistent messages to a destination targeted to a JMS server that does not have a persistent store configured. This parameter only has effect when the Store Enabled parameter is disabled (false).  When set to false, the default, clients will get an exception when sending persistent messages to a JMS server with no store configured. When set to true, then persistent messages are downgraded to non-persistent; however, the send operations are allowed to continue.

  An example on how to use this:

      wls_jmsserver {a_wls_jmsserver :
         ...
         allows_persistent_downgrade => 1,
         ...
      }

  DESC

  data_type("Optional[Variant[Enum['absent'],Integer[0,1]]]")
  maps_to('AllowsPersistentDowngrade')
end
