# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:message_compression_options, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  Specifies the type of message compression used when JMS message body compression is enabled for Persistent Stores and JMS Paging Stores. <ul> <li>Use <code>GZIP_DEFAULT_COMPRESSION</code> to enable message compression using the JDK GZIP API with <code>DEFAULT_COMPRESSION</code> level.</li> <li>Use <code>GZIP_BEST_COMPRESSION</code> to enable message compression using the JDK GZIP API with <code>BEST_COMPRESSION</code> level. <li>Use <code>GZIP_BEST_SPEED</code> to enable message compression using the JDK GZIP API with <code>BEST_SPEED</code> level. <li>Use <code>LZF</code> to enable message compression using Open Source LZF. </ul> This attribute should be used only when configuring a WebLogic domain in an Oracle Exalogic environment.

  An example on how to use this:

      wls_jmsserver {a_wls_jmsserver :
         ...
         message_compression_options => 'GZIP_DEFAULT_COMPRESSION'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_jmsserver:message_compression_options']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  data_type('Optional[String]')

  maps_to('MessageCompressionOptions')
end
