# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newparam(:action) do
  include EasyType

  desc <<-DESC
    The kind of action you want to manage with this security policy.

    This is the last part of the title of the resource. Here is an example:

        wls_jndi_security_policy{'domain/server:javax.erb.com:lookup'
          ...
        }

    In this example `lookup` is the action. So this is a policy that says something
    about the rights you need to do do a jndi lookup on `javax.erb.com`.


  DESC

  isnamevar

  newvalues('all', 'lookup', 'modify', 'list')

  defaultto('all')

  to_translate_to_resource do |raw_resource|
    raw_resource['action']
  end
  data_type("Optional[Enum['all', 'lookup', 'modify', 'list']]")
end
