# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:preserve_msg_property, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  Specifies if message properties are preserved when messages are forwarded by a bridge instance.  If the target bridge destination is on wls 9.0 or higher, the following message properties are preserved:  <ul> <li> <code>message ID</code> </li>  <li> <code>message timestamp</code> </li>  <li> <code>user ID</code> </li>  <li> <code>delivery mode</code> </li>  <li> <code>priority</code> </li>  <li> <code>expiration time</code> </li>  <li> <code>redelivery limit</code> </li>  <li> <code>unit of order name</code> </li> </ul>  If the target bridge destination is on wls between 6.0 and 8.1 or on a foreign JMS server, the following message properties are preserved:  <ul> <li> <code>delivery mode</code> </li>  <li> <code>priority</code> </li>  <li> <code>expiration time</code> </li> </ul>  If the target bridge destination is on wls 5.1 or older, no properties are preserved.

  An example on how to use this:

      wls_messaging_bridge {a_wls_messaging_bridge :
         ...
         preserve_msg_property => 1,
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_messaging_bridge:preserve_msg_property']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  include Puppet_X::EnterpriseModules::WebLogic::Types::NumberedBoolean
  data_type("Optional[Variant[Enum['absent'],Integer[0,1]]]")

  maps_to('PreserveMsgProperty')
end
