# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:driver_name, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  The full package name of JDBC driver class used to create the physical database connections in the connection pool in the data source.  For example: <code>oracle.jdbc.OracleDriver</code>  The driver must be the name of a class that implements the <code>java.sql.Driver</code> interface. Check the driver documentation to find the full pathname.  Note that the driver class must be in the classpath of any server to which the data source is deployed.

  An example on how to use this:

      wls_multi_datasource {a_wls_multi_datasource :
         ...
         driver_name => 'a_value'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_multi_datasource:driver_name']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  data_type('Optional[String]')

  maps_to('JDBCResource/%<multi_datasource_name>s/JDBCDriverParams/%<multi_datasource_name>s/DriverName')
end
