# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:ds_algorithm_type, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  The algorithm determines the connection request processing for the multi data source.  You can specify one of the following algorithm types:  <ul> <li>Failover  Connection requests are sent to the first data source in the list; if the request fails, the request is sent to the next data source in the list, and so forth. The process is repeated until a valid connection is obtained, or until the end of the list is reached, in which case an exception is thrown. </li>  <li>Load balancing  The multi data source distributes connection requests evenly to its member data sources. With this algorithm, the multi data source also provides failover processing. That is, if a request fails, the multi data source sends the request to the next data source in the list until a valid connection is obtained, or until the end of the list is reached, in which case an exception is thrown. </li> </ul>

  An example on how to use this:

      wls_multi_datasource {a_wls_multi_datasource :
         ...
         ds_algorithm_type => 'Failover'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_multi_datasource:ds_algorithm_type']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  data_type('Optional[String]')

  maps_to('JDBCResource/%<multi_datasource_name>s/JDBCDataSourceParams/%<multi_datasource_name>s/AlgorithmType')
end
