# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:ds_keep_conn_after_global_tx, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  Enables WebLogic Server to keep the physical database connection associated with the logical connection when committing a global transaction instead releasing it and getting another physical connection when needed.  Setting this option to true may require additional connections to be configured on the database.  Use this setting to work around specific problems with JDBC XA drivers.

  An example on how to use this:

      wls_multi_datasource {a_wls_multi_datasource :
         ...
         ds_keep_conn_after_global_tx => 1,
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_multi_datasource:ds_keep_conn_after_global_tx']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  include Puppet_X::EnterpriseModules::WebLogic::Types::NumberedBoolean
  data_type("Optional[Variant[Enum['absent'],Integer[0,1]]]")

  maps_to('JDBCResource/%<multi_datasource_name>s/JDBCDataSourceParams/%<multi_datasource_name>s/KeepConnAfterGlobalTx')
end
