# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:pool_seconds_to_trust_an_idle_pool_connection, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  The number of seconds within a connection use that WebLogic Server trusts that the connection is still viable and will skip the connection test, either before delivering it to an application or during the periodic connection testing process.  This option is an optimization that minimizes the performance impact of connection testing, especially during heavy traffic.

  An example on how to use this:

      wls_multi_datasource {a_wls_multi_datasource :
         ...
         pool_seconds_to_trust_an_idle_pool_connection => '10'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_multi_datasource:pool_seconds_to_trust_an_idle_pool_connection']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC
  include EasyType::Types::Integer
  data_type("Optional[Variant[Enum['absent'],Integer]]")

  maps_to('JDBCResource/%<multi_datasource_name>s/JDBCConnectionPoolParams/%<multi_datasource_name>s/SecondsToTrustAnIdlePoolConnection')
end
