# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:policy, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  The error handling policy for this SAF error handling resource. <ul> <li> Discard - By default, expired messages are simply removed from the system. The removal is not logged and the message is not redirected to another location.</li> <li> Log - Removes expired messages and writes an entry to the server log file indicating that the messages were removed from the system. You define the actual information that will be logged in the Log Format field.</li> <li> Redirect - Moves expired messages from their current location into the Error Destination defined for imported SAF destinations.</li> <li> Always-Forward - Ignores the SAF Default Time-to-Live value set on the imported destination and the expiration time set on the message, and so forwards the message to a remote destination even after it has expired.</li> </ul>  Any change to this parameter affects only incoming messages; stored messages are not affected.

  An example on how to use this:

      wls_saf_error_handler {a_wls_saf_error_handler :
         ...
         policy => 'Discard'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_saf_error_handler:policy']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  maps_to('Policy')
end
