# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:non_persistent_qos, :parent => Puppet::Parameter::WlsProperty) do
  extend SAFImportedDestinationObjectProperty

  desc <<-DESC
  Specifies the quality-of-service for non-persistent messages. <ul> <li> <code>Exactly-Once</code> indicates that messages will be forwarded to the remote side once and only once except for any occurrence of server crashes. </li> <li> <code>At-Least-Once</code> indicates that messages will be forwarded to the remote side at least once. No message will be lost except for any occurrence of server crashes. However, messages may appear in the remote endpoint more than once. </li> <li> <code>At-Most-Once</code> indicates that messages will be forwarded to the remote side atmost once. No message will appear in the remote endpoint more than once. However, messages may get lost. </li> </ul> Any change to this parameter affects only incoming messages; stored messages are not affected.

  An example on how to use this:

      wls_saf_imported_destination_object {a_wls_saf_imported_destination_object :
         ...
         non_persistent_qos => 'At-Least-Once'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_saf_imported_destination_object:non_persistent_qos']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  maps_to('NonPersistentQos')
end
