# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:login_password, :parent => Puppet::Parameter::WlsEncryptedProperty) do
  desc <<-DESC
  The password for the username used to log into the remote URL.  When Password is specified for a SAFLoginContext, then SAFPrincipalName is not specified.

  An example on how to use this:

      wls_saf_remote_context {a_wls_saf_remote_context :
         ...
         login_password => 'a_value'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_saf_remote_context:login_password']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  maps_to('SAFLoginContext/%<remote_context_name>s/Password')
end
