# frozen_string_literal: true

newproperty(:delegate_mbean_authorization, :parent => Puppet::Parameter::WlsProperty) do
  include Puppet_X::EnterpriseModules::WebLogic::Types::NumberedBoolean

  desc <<-DESC
  Configures the WebLogic Server MBean servers to use the security realm's Authorization providers to determine whether a JMX client has permission to access an MBean attribute or invoke an MBean operation. You can continue to use WebLogic Server's default security settings or modify the defaults to suit your needs. If you do not delegate authorization to the realm's Authorization providers, the WebLogic MBean servers allow access only to the four default security roles (Admin, Deployer, Operator, and Monitor) and only as specified by WebLogic Server's default security settings.

  An example on how to use this:

      wls_security_realm {a_wls_security_realm :
         ...
         delegate_mbean_authorization => 1,
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  data_type("Optional[Variant[Enum['absent'],Integer[0,1]]]")

  maps_to('DelegateMBeanAuthorization')
end
