# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:auto_restart, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  Specifies whether the Node Manager can automatically restart this server if it crashes or otherwise goes down unexpectedly.

  An example on how to use this:

      wls_server {a_wls_server :
         ...
         auto_restart => 1,
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_server:auto_restart']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  include Puppet_X::EnterpriseModules::WebLogic::Types::NumberedBoolean
  data_type("Optional[Variant[Enum['absent'],Integer[0,1]]]")

  maps_to('AutoRestart')
end
