# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:classpath_servlet_disabled, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  The ClasspathServlet will serve any class file in the classpath and is registered by default in every Web application (including management). It does not need to be turned on for many applications though, and represents a security hole if unchecked.

  An example on how to use this:

      wls_server {a_wls_server :
         ...
         classpath_servlet_disabled => 1,
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_server:classpath_servlet_disabled']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  include Puppet_X::EnterpriseModules::WebLogic::Types::NumberedBoolean
  data_type("Optional[Variant[Enum['absent'],Integer[0,1]]]")

  maps_to('ClasspathServletDisabled')
end
