# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:overload_server_failure_trigger, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  Configure a trigger that marks the server as failed when the condition is met. A failed server in turn can be configured to shutdown or go into admin state.

  An example on how to use this:

      wls_server {a_wls_server :
         ...
         overload_server_failure_trigger => 'a_value'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_server:overload_server_failure_trigger']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  maps_to('OverloadProtection/%<server_name>s/ServerFailureTrigger')
end
