# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:use81_style_execute_queues, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  Backward compatibility mode to switch to 8.1 execute queues instead of WorkManagers. Each of the WorkManagers is converted to an individual execute queue. Setting this attribute requires a server restart.

  An example on how to use this:

      wls_server {a_wls_server :
         ...
         use81_style_execute_queues => 1,
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_server:use81_style_execute_queues']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  include Puppet_X::EnterpriseModules::WebLogic::Types::NumberedBoolean
  data_type("Optional[Variant[Enum['absent'],Integer[0,1]]]")

  maps_to('Use81StyleExecuteQueues')
end
