# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:webserver_accept_context_path_in_get_real_path, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  Indicates whether this server allows the inclusion of the context path in the virtual path to <code>context.getRealPath()</code>. (If checked, you cannot use sub directories with the same name as <code>contextPath</code>). This is a compatibility switch that will be deprecated 9.0.0.0 in future releases.  Gets the acceptContextPathInGetRealPath attribute of the WebServerMBean object

  An example on how to use this:

      wls_server {a_wls_server :
         ...
         webserver_accept_context_path_in_get_real_path => '1'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_server:webserver_accept_context_path_in_get_real_path']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  include Puppet_X::EnterpriseModules::WebLogic::Types::NumberedBoolean

  maps_to('WebServer/%<server_name>s/AcceptContextPathInGetRealPath')
end
