# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:channel_identity_customized, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  Whether or not the channel's custom identity should be used. This setting only has an effect if the server is using a customized keystore. By default the channel's identity is inherited from the server's identity.

  An example on how to use this:

      wls_server_channel {a_wls_server_channel :
         ...
         channel_identity_customized => 1,
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_server_channel:channel_identity_customized']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  data_type("Optional[Variant[Enum['absent'],Integer[0,1]]]")

  include Puppet_X::EnterpriseModules::WebLogic::Types::NumberedBoolean

  maps_to('ChannelIdentityCustomized')
end
