# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:idle_connection_timeout, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  The maximum amount of time (in seconds) that a connection is allowed to be idle before it is closed by this network channel. A value of <tt>-1</tt> indicates that the network channel obtains this timeout value from the ServerTemplateMBean.  This timeout helps guard against server deadlock through too many open connections.

  An example on how to use this:

      wls_server_channel {a_wls_server_channel :
         ...
         idle_connection_timeout => 'a_value'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_server_channel:idle_connection_timeout']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  maps_to('IdleConnectionTimeout')
end
