# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:enabled, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  When true, TLOGs are logged to a TLOG JDBC Store; otherwise, TLOGs are logged to the server's default store. When using the Administration Console, select JDBC to enable logging of TLOGs to a JDBC store; select Default Store to enable logging of TLOGs to the server's default store.

  An example on how to use this:

      wls_server_tlog {a_wls_server_tlog :
         ...
         enabled => 1,
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_server_tlog:enabled']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  include Puppet_X::EnterpriseModules::WebLogic::Types::NumberedBoolean
  data_type("Optional[Variant[Enum['absent'],Integer[0,1]]]")

  maps_to('Enabled')
end
