# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:initial_boot_delay_seconds, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  Specifies the amount of time, in seconds, to delay before starting a cluster targeted JMS instance on a newly booted WebLogic server. When this setting is configured on a Store it applies to all JMS artifacts that reference the store.  This allows time for the system to stabilize and dependent services to be restarted, preventing a system failure during a reboot.  <ul> <li>A value > <code>0</code> is the time, in seconds, to delay before before loading resources after a failure and restart.</li> <li>A value of <code>0</code> specifies no delay.</li> <li>A value of <code>-1</code> specifies the default delay value is used.</li> </ul> Note: This setting only applies when the JMS artifact is cluster targeted and the Migration Policy is set to <code>On-Failure</code> or <code>Always></code>.

  An example on how to use this:

      wls_server_tlog {a_wls_server_tlog :
         ...
         initial_boot_delay_seconds => '-1'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_server_tlog:initial_boot_delay_seconds']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  maps_to('InitialBootDelaySeconds')
end
