# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
$LOAD_PATH.unshift File.join(File.dirname(__FILE__), '../..')
require 'puppet_x/enterprisemodules/weblogic/core'

module Puppet
  Type.newtype(:wls_singleton_service) do
    include Puppet_X::EnterpriseModules::WebLogic::Type

    desc <<-DESC
      This resource allows you to managed singleton services in a WebLogic domain.

      Here is an example on how you should use this:

          wls_singleton_service { 'SingletonService':
              ensure                           => 'present',
              cluster                          => 'ClusterName',
              user_preferred_server            => 'PreferredServerName',
              class_name                       => 'com.example.package.SingletonServiceImpl',
              constrained_candidate_servers    => ['PreferredServerName', 'OtherServerName'],
              additional_migration_attempts    => 2,
              millis_to_sleep_between_attempts => 300000,
              notes                            => 'This is a singleton service that prefers to run on PreferredServerName, but can be migrated to OtherServerName.',
          }

      In this example you are managing a singleton service in the default domain. When you want to
      manage a singleton service in a specific domain, you can use:

            wls_singleton_service { 'my_domain/SingletonService':
              ensure                           => 'present',
              cluster                          => 'ClusterName',
              user_preferred_server            => 'PreferredServerName',
              class_name                       => 'com.example.package.SingletonServiceImpl',
              constrained_candidate_servers    => ['PreferredServerName', 'OtherServerName'],
              additional_migration_attempts    => 2,
              millis_to_sleep_between_attempts => 300000,
              notes                            => 'This is a singleton service that prefers to run on PreferredServerName, but can be migrated to OtherServerName.',
          }

    DESC

    bean_type('SingletonService')

    ensurable
    parameter :domain
    parameter :name
    parameter :singleton_service_name
    property :cluster
    property :class_name
    property :additional_migration_attempts
    property :millis_to_sleep_between_attempts
    property :notes
    property :constrained_candidate_servers
    property :user_preferred_server
    extraproperties do
      property :hosting_server
      property :tags
    end

    add_title_attributes(:singleton_service_name)
  end
end
